@@ -1,11 +1,17 @@
 ame_frn <-
 function(Y,X,odmax=rep(max(apply(Y>0,1,sum,na.rm=TRUE)),nrow(Y)),
-                  rvar=TRUE,cvar=TRUE,dcor=TRUE,R=1,
+                  rvar=TRUE,cvar=TRUE,dcor=TRUE,R=0,
                   seed=1,nscan=5e4,burn=5e2,odens=25,plot=TRUE,print=TRUE)
 {
 
 diag(Y)<-NA
 
+if( length(dim(X))==2 ) { X<-array(X,dim=c(dim(X),1)) }
+if(  !any(apply(X,3,function(x){var(c(x))})==0)  )
+{cat("WARNING: design matrix lacks an intercept","\n") }
+
+
+
 ## marginal means and regression sums of squares
 Xr<-apply(X,c(1,3),sum)            # row sum
 Xc<-apply(X,c(2,3),sum)            # col sum
